@@ -1,4 +1,3 @@
-formats <- list()
 formats$csfmt_rts_data_v1 <- list()
 formats$csfmt_rts_data_v1$unified <- list()
 formats$csfmt_rts_data_v1$unified$granularity_time <- list(
@@ -114,67 +113,6 @@ formats$csfmt_rts_data_v1$unified$date <- list(
   class = "Date"
 )
 
-#' Remove class csfmt_rts_data_*
-#' @param x data.table
-#' @examples
-#' x <- cstidy::generate_test_data() %>%
-#'   cstidy::set_csfmt_rts_data_v1()
-#' class(x)
-#' cstidy::remove_class_csfmt_rts_data(x)
-#' class(x)
-#' @family csfmt_rts_data
-#' @returns No return value, called for the side effect of removing the csfmt_rts_data class from x.
-#' @export
-remove_class_csfmt_rts_data <- function(x) {
-  classes <- class(x)
-  classes <- classes[!stringr::str_detect(classes, "^csfmt_rts_data_")]
-  setattr(x, "class", classes)
-  return(invisible(x))
-}
-
-
-#' Generate test data
-#'
-#' @description
-#' Generates some test data
-#'
-#' @param fmt Data format (\code{csfmt_rts_data_v1})
-#' @examples
-#' cstidy::generate_test_data("csfmt_rts_data_v1")
-#' @returns csfmt_rts_data_v1, a dataset containing fake data.
-#' @export
-generate_test_data <- function(fmt = "csfmt_rts_data_v1") {
-  granularity_geo <- NULL
-  granularity_time <- NULL
-  isoyearweek <- NULL
-  deaths_n <- NULL
-  isoyear <- NULL
-  age <- NULL
-  sex <- NULL
-
-  stopifnot(fmt %in% c("csfmt_rts_data_v1"))
-
-  if (fmt == "csfmt_rts_data_v1") {
-    d1 <- data.table(location_code = csdata::nor_locations_names()[granularity_geo == "county"]$location_code)
-    d1[, granularity_time := "isoyearweek"]
-    d1[, isoyearweek := "2022-03"]
-    d1[, deaths_n := stats::rpois(.N, 5)]
-
-    d2 <- copy(d1)
-    d2[, isoyear := 2022]
-    d2[, age := "total"]
-    d2[, sex := "total"]
-
-    d3 <- copy(d1)
-    d3[, isoyear := 2022]
-    d3[, age := "000_005"]
-    d3[, sex := "total"]
-
-    d <- rbind(d1, d2, d3, fill = T)
-  }
-  return(d)
-}
-
 # print.csfmt_rts_data_v1 <- function(x, ...) {
 #   # https://cran.r-project.org/web/packages/data.table/vignettes/datatable-faq.html#ok-thanks.-what-was-so-difficult-about-the-result-of-dti-col-value-being-returned-invisibly
 #   if (!data.table::shouldPrint(x)) {
@@ -299,7 +237,7 @@ generate_test_data <- function(fmt = "csfmt_rts_data_v1") {
 #   csutil::apply_fn_via_hash_table(x, heal_time_csfmt_rts_data_v1_internal, cols=cols, from=from)
 # }
 
-#' Provides corresponding healed times
+#' Provides corresponding healed times (deprecated)
 #' @param x A vector containing either dates, isoyearweek, or isoyear.
 #' @param cols Columns to restrict the output to.
 #' @param granularity_time date, isoyearweek, or isoyear, depending on the values contained in x.
@@ -434,46 +372,12 @@ heal_time_csfmt_rts_data_v1 <- function(x, cols, granularity_time = "date"){
       }
 
       if (time_var_modified == "isoyear") {
-        # healing_options <- list(
-        #   "granularity_time" = "\"isoyear\"",
-        #   "isoweek" = "cstime::isoyear_to_last_isoweek_n(isoyear)",
-        #   "isoyearweek" = "cstime::isoyear_to_last_isoyearweek_c(isoyear)",
-        #   "season" = "NA_character_",
-        #   "seasonweek" = "NA_real_",
-        #   "calyear" = "NA_integer_",
-        #   "calmonth" = "NA_integer_",
-        #   "calyearmonth" = "NA_character_",
-        #   "date" = "cstime::isoyear_to_last_date(isoyear)"
-        # )
         healing_options <- names(heal_time_csfmt_rts_data_v1(2020, names(x), granularity_time="isoyear"))
         healing_function <- glue::glue('cstidy::heal_time_csfmt_rts_data_v1(isoyear, c("{paste0(healing_options, collapse="\\",\\"")}"), granularity_time=\"isoyear\")')
       } else if (time_var_modified == "isoyearweek") {
-        # healing_options <- list(
-        #   "granularity_time" = "\"isoweek\"",
-        #   "isoyear" = "cstime::isoyearweek_to_isoyear_n(isoyearweek)",
-        #   "isoweek" = "cstime::isoyearweek_to_isoweek_n(isoyearweek)",
-        #   "season" = "cstime::isoyearweek_to_season_c(isoyearweek)",
-        #   "seasonweek" = "cstime::isoyearweek_to_seasonweek_n(isoyearweek)",
-        #   "calyear" = "NA_integer_",
-        #   "calmonth" = "NA_integer_",
-        #   "calyearmonth" = "NA_character_",
-        #   "date" = "cstime::isoyearweek_to_last_date(isoyearweek)"
-        # )
         healing_options <- names(heal_time_csfmt_rts_data_v1("2020-01", names(x), granularity_time="isoyearweek"))
         healing_function <- glue::glue('cstidy::heal_time_csfmt_rts_data_v1(isoyearweek, c("{paste0(healing_options, collapse="\\",\\"")}"), granularity_time=\"isoyearweek\")')
-
       } else if (time_var_modified == "date") {
-        # healing_options <- list(
-        #   "granularity_time" = "\"day\"",
-        #   "isoyear" = "cstime::date_to_isoyear_n(date)",
-        #   "isoweek" = "cstime::date_to_isoweek_n(date)",
-        #   "isoyearweek" = "cstime::date_to_isoyearweek_c(date)",
-        #   "season" = "cstime::date_to_season_c(date)",
-        #   "seasonweek" = "cstime::date_to_seasonweek_n(date)",
-        #   "calyear" = "cstime::date_to_calyear_n(date)",
-        #   "calmonth" = "cstime::date_to_calmonth_n(date)",
-        #   "calyearmonth" = "cstime::date_to_calyearmonth_c(date)"
-        # )
         healing_options <- names(heal_time_csfmt_rts_data_v1(as.Date("2020-01-01"), names(x), granularity_time="date"))
         healing_function <- glue::glue('cstidy::heal_time_csfmt_rts_data_v1(date, c("{paste0(healing_options, collapse="\\",\\"")}"), granularity_time=\"date\")')
       } else {
@@ -481,18 +385,6 @@ heal_time_csfmt_rts_data_v1 <- function(x, cols, granularity_time = "date"){
         healing_function <- NULL
       }
 
-      # if (!is.null(healing_options)) {
-      #   healing_options <- healing_options[names(healing_options) %in% names(x)]
-      #   if (length(healing_options) > 0) {
-      #     healing_calls[[length(healing_calls) + 1]] <- glue::glue(
-      #       '{orig_call[[2]]}[!is.na(x_modified_timevar_97531),
-      #       c("{paste0(names(healing_options), collapse="\\",\\"")}")
-      #       :=
-      #       .({paste0(healing_options, collapse=",")})
-      #       ]'
-      #     )
-      #   }
-      # }
       if (!is.null(healing_options)) {
         healing_calls[[length(healing_calls) + 1]] <- glue::glue(
           '{orig_call[[2]]}[!is.na(x_modified_timevar_97531),
@@ -581,10 +473,6 @@ heal_time_csfmt_rts_data_v1 <- function(x, cols, granularity_time = "date"){
   }
 }
 
-heal <- function(x, ...) {
-  UseMethod("heal", x)
-}
-
 heal.csfmt_rts_data_v1 <- function(x, ...) {
   granularity_time <- NULL
   original_granularity_time_32423432 <- NULL
@@ -739,10 +627,6 @@ heal.csfmt_rts_data_v1 <- function(x, ...) {
   return(invisible(x))
 }
 
-create_unified_columns <- function(x, ...) {
-  UseMethod("create_unified_columns", x)
-}
-
 create_unified_columns.csfmt_rts_data_v1 <- function(x, ...) {
   fmt <- attr(x, "format_unified")
   for (i in names(fmt)) {
@@ -762,10 +646,6 @@ create_unified_columns.csfmt_rts_data_v1 <- function(x, ...) {
   return(invisible(x))
 }
 
-assert_classes <- function(x, ...) {
-  UseMethod("assert_classes", x)
-}
-
 assert_classes.csfmt_rts_data_v1 <- function(x, ...) {
   fmt <- attr(x, "format_unified")
   classes_real <- lapply(x, class)
@@ -792,7 +672,7 @@ assert_classes.csfmt_rts_data_v1 <- function(x, ...) {
   return(invisible(x))
 }
 
-#' Convert data.table to csfmt_rts_data_v1
+#' Convert data.table to csfmt_rts_data_v1 (deprecated)
 #'
 #' @description
 #' \code{set_csfmt_rts_data_v1} converts a \code{data.table} to \code{csfmt_rts_data_v1} by reference.
@@ -859,44 +739,11 @@ assert_classes.csfmt_rts_data_v1 <- function(x, ...) {
 #' - calyearmonth
 #' - date
 #'
-#' @details
-#' For more details see the vignette:
-#' \code{vignette("csfmt_rts_data_v1", package = "cstidy")}
-#'
 #' @return An extended \code{data.table}, which has been modified by reference and returned (invisibly).
 #'
 #' @param x The data.table to be converted to csfmt_rts_data_v1
 #' @param create_unified_columns Do you want it to create unified columns?
 #' @param heal Do you want to impute missing values on creation?
-#' @examples
-#' # Create some fake data as data.table
-#' d <- cstidy::generate_test_data(fmt = "csfmt_rts_data_v1")
-#' d <- d[1:5]
-#'
-#' # convert to csfmt_rts_data_v1 by reference
-#' cstidy::set_csfmt_rts_data_v1(d, create_unified_columns = TRUE)
-#'
-#' #
-#' d[1, isoyearweek := "2021-01"]
-#' d
-#' d[2, isoyear := 2019]
-#' d
-#' d[3, date := as.Date("2020-01-01")]
-#' d
-#' d[4, c("isoyear", "isoyearweek") := .(2021, "2021-01")]
-#' d
-#' d[5, c("location_code") := .("norge")]
-#' d
-#'
-#' # Investigating the data structure of one column inside a dataset
-#' cstidy::generate_test_data() %>%
-#'   cstidy::set_csfmt_rts_data_v1() %>%
-#'   cstidy::identify_data_structure("deaths_n") %>%
-#'   plot()
-#' # Investigating the data structure via summary
-#' cstidy::generate_test_data() %>%
-#'   cstidy::set_csfmt_rts_data_v1() %>%
-#'   summary()
 #' @family csfmt_rts_data
 #' @returns No return value, called for side effect of replacing the current data.table with a csfmt_rts_data_v1 in place.
 #' @export
@@ -934,42 +781,6 @@ csfmt_rts_data_v1 <- function(x, create_unified_columns = TRUE, heal = TRUE) {
   return(y)
 }
 
-validate <- function(x) {
-  new_hash <- digest::digest(attr(x, ".internal.selfref"), "md5")
-  old_hash <- attr(x, "hash")
-
-  # data hasnt changed since last validation
-  if (identical(new_hash, old_hash)) {
-    # return(invisible())
-  }
-  status <- attr(x, "status")
-  if (is.null(status)) status <- list()
-
-  fmt <- attr(x, "format_unified")
-  for (i in names(fmt)) {
-    fmt_i <- fmt[[i]]
-    status_i <- list()
-    status_i$errors <- "\U274C Errors:"
-
-    # variable doesn't exist
-    if (!i %in% names(x)) {
-      status_i$errors <- paste0(status_i$errors, "\n- Variable doesn't exist")
-    } else {
-      # check for NAs allowed
-      if (fmt_i$NA_allowed == FALSE & sum(is.na(x[[i]])) > 0) {
-        status_i$errors <- paste0(status_i$errors, "\n- NA exists (not allowed)")
-      }
-      # if(!is.null())
-
-      if (status_i$errors == "\U274C Errors:") status_i$errors <- "\U2705 No errors"
-    }
-    status[[i]] <- status_i
-  }
-
-  setattr(x, "status", status)
-  setattr(x, "hash", new_hash)
-}
-
 #' @method summary csfmt_rts_data_v1
 #' @returns No return value, called for side effect of printing a summary of the object.
 #' @export
@@ -1070,211 +881,7 @@ summary.csfmt_rts_data_v1 <- function(object, ...) {
   cat("\n")
 }
 
-#' Hash the data structure of a dataset for a given column
-#'
-#' @description
-#' Reduces the data structure of a column inside a dataset into something that describes
-#'
-#' @param x An object
-#' @param col Column name to hash
-#' @param ... Arguments passed to or from other methods
-#' @examples
-#' cstidy::generate_test_data() %>%
-#'   cstidy::set_csfmt_rts_data_v1() %>%
-#'   cstidy::identify_data_structure("deaths_n") %>%
-#'   plot()
-#' @family csfmt_rts_data
-#' @returns csfmt_rts_data_structure_hash_v1, a summary object.
-#' @rdname identify_data_structure
-#' @export
-identify_data_structure <- function(x, col, ...) {
-  UseMethod("identify_data_structure", x)
-}
 
-identify_data_structure_internal <- function(summarized, col) {
-  . <- NULL
-  num_valid <- NULL
-  num_na <- NULL
-  category <- NULL
-  age <- NULL
-  sex <- NULL
-  granularity_geo <- NULL
-  # we expect a data.table with columns:
-  # - granularity_time
-  # - granularity_geo
-  # - age
-  # - sex
-  # - num_valid
-  # - num_na
-
-  skeleton <- CJ(
-    granularity_time = c("isoyear", "isoyearweek", "date"),
-    granularity_geo = unique(csdata::nor_locations_names()$granularity_geo),
-    age = unique(summarized$age),
-    sex = unique(summarized$sex)
-  )
-  skeleton[
-    summarized,
-    on = c("granularity_time", "granularity_geo", "age", "sex"),
-    c("num_valid", "num_na") := .(num_valid, num_na)
-  ]
-  skeleton[is.na(num_valid), num_valid := 0]
-  skeleton[is.na(num_na), num_na := 0]
-
-  skeleton[, category := dplyr::case_when(
-    num_valid == 0 & num_na == 0 ~ "structurally_missing",
-    num_valid == 0 & num_na > 0 ~ "only_na",
-    num_valid > 0 & num_na == 0 ~ "only_data",
-    num_valid > 0 & num_na > 0 ~ "data_and_na",
-  )]
-  skeleton[is.na(age), age := "missing"]
-  skeleton[is.na(sex), sex := "missing"]
-
-  skeleton[, num_valid := NULL]
-  skeleton[, num_na := NULL]
-  skeleton[, granularity_geo := factor(granularity_geo, levels = unique(csdata::nor_locations_names()$granularity_geo))]
-
-  # check if can merge together age groups
-  skeleton_wide <- dcast.data.table(
-    skeleton,
-    granularity_time + granularity_geo + sex ~ age,
-    value.var = "category"
-  )
-
-  equality <- diag(ncol(skeleton_wide)-3)
-  colnames(equality) <- names(skeleton_wide)[4:ncol(skeleton_wide)]
-  rownames(equality) <- names(skeleton_wide)[4:ncol(skeleton_wide)]
-  for (i in 4:ncol(skeleton_wide)) {
-    for (j in 4:ncol(skeleton_wide)) {
-      if (sum(skeleton_wide[[i]] != skeleton_wide[[j]]) == 0) equality[i - 3, j - 3] <- 1
-    }
-  }
-  while (nrow(equality) > 0) {
-    if (sum(equality[1, ]) > 1) {
-      names_to_sum <- colnames(equality)[equality[1, ] == 1]
-      end_name <- paste0(names_to_sum, collapse = ",")
-      skeleton_wide[, (end_name) := get(names_to_sum[1])]
-      for (i in names_to_sum) {
-        # delete the data in the skeleton
-        skeleton_wide[, (i) := NULL]
-        # delete the data in the equality matrix
-        equality <- equality[-which(rownames(equality) == i), , drop = FALSE]
-      }
-    } else {
-      equality <- equality[-1, , drop = FALSE]
-    }
-  }
-
-  skeleton <- melt.data.table(
-    skeleton_wide,
-    id.vars = c("granularity_time", "granularity_geo", "sex"),
-    variable.factor = FALSE,
-    variable.name = "age",
-    value.name = "category"
-  )
-
-  skeleton_wide <- dcast.data.table(
-    skeleton,
-    granularity_time + age + sex ~ granularity_geo,
-    value.var = "category"
-  )
-
-  # delete columns that are just structurally_missing and furthest to the right
-  for (i in rev(names(skeleton_wide))) {
-    if (i == "municip") {
-      break()
-    } else if (sum(skeleton_wide[[i]] != "structurally_missing", na.rm = T) == 0) {
-      skeleton_wide[, (i) := NULL]
-    } else {
-      break()
-    }
-  }
-
-  skeleton_long <- melt.data.table(
-    skeleton_wide,
-    id.vars = c("granularity_time", "age", "sex"),
-    variable.factor = FALSE,
-    variable.name = "granularity_geo",
-    value.name = "category"
-  )
-
-  setattr(skeleton_long, "class", unique(c("csfmt_rts_data_structure_hash_v1", class(skeleton_long))))
-
-  return(invisible(skeleton_long))
-}
-
-#' @method identify_data_structure csfmt_rts_data_v1
-#' @rdname identify_data_structure
-#' @export
-identify_data_structure.csfmt_rts_data_v1 <- function(x, col, ...) {
-  . <- NULL
-  granularity_time <- NULL
-  granularity_geo <- NULL
-  age <- NULL
-  sex <- NULL
-  var <- NULL
-  # col <-
-  # Take in the data table
-  # data <- data$cases
-  # data <- data$vax
-
-  summarized <- x[, .(
-    num_valid = sum(!is.na(get(col))),
-    num_na = sum(is.na(get(col)))
-  ),
-  keyby = .(
-    granularity_time,
-    granularity_geo,
-    age,
-    sex
-  )
-  ]
-
-  identify_data_structure_internal(
-    summarized,
-    var
-  )
-}
-
-#' @rdname identify_data_structure
-#' @export
-"identify_data_structure.tbl_Microsoft SQL Server" <- function(x, col, ...) {
-  granularity_time <- NULL
-  granularity_geo <- NULL
-  age <- NULL
-  sex <- NULL
-  n <- NULL
-  num_total <- NULL
-  num_na <- NULL
-  # col <-
-  # Take in the data table
-  # data <- data$cases
-  # data <- data$vax
-
-  summarized <- x %>%
-    dplyr::rename(col = !!col) %>%
-    dplyr::group_by(
-      granularity_time,
-      granularity_geo,
-      age,
-      sex
-    ) %>%
-    dplyr::summarize(
-      num_total = n(),
-      num_na = sum(as.numeric(is.na(col)))
-    ) %>%
-    dplyr::mutate(
-      num_valid = num_total - num_na
-    ) %>%
-    dplyr::select(-num_total) %>%
-    dplyr::collect() %>%
-    as.data.table()
-
-  identify_data_structure_internal(
-    summarized,
-    col
-  )
-}
 
 #' @method plot csfmt_rts_data_structure_hash_v1
 #' @export
@@ -1305,34 +912,6 @@ plot.csfmt_rts_data_structure_hash_v1 <- function(x, y, ...) {
   q
 }
 
-
-
-#' Unique time series
-#'
-#' @description
-#' Attempts to identify the unique time series that exist in this dataset.
-#'
-#' A time series is defined as a unique combination of:
-#' - granularity_time
-#' - granularity_geo
-#' - country_iso3
-#' - location_code
-#' - border
-#' - age
-#' - sex
-#' - *_id
-#' - *_tag
-#'
-#' @param x An object of type \code{\link{csfmt_rts_data_v1}}
-#' @param set_time_series_id If TRUE, then `x` will have a new column called 'time_series_id'
-#' @param ... Not used.
-#' @returns data.table, a dataset that lists all the unique time series in x.
-#' @family csfmt_rts_data
-#' @export
-unique_time_series <- function(x, set_time_series_id = FALSE, ...) {
-  UseMethod("unique_time_series", x)
-}
-
 #' @method unique_time_series csfmt_rts_data_v1
 #' @export
 unique_time_series.csfmt_rts_data_v1 <- function(x, set_time_series_id = FALSE, ...) {
@@ -1355,6 +934,7 @@ unique_time_series.csfmt_rts_data_v1 <- function(x, set_time_series_id = FALSE,
   retval <- x[, ids, with=F] %>%
     unique() %>%
     remove_class_csfmt_rts_data()
+  data.table::shouldPrint(retval)
 
   # don't do anything, if "time_series_id" already exists in x
   if("time_series_id" %in% names(retval)){
@@ -1370,34 +950,6 @@ unique_time_series.csfmt_rts_data_v1 <- function(x, set_time_series_id = FALSE,
   return(retval)
 }
 
-#' Expand time to
-#'
-#' @description
-#' Attempts to expand the dataset to include more time
-#'
-#' A time series is defined as a unique combination of:
-#' - granularity_time
-#' - granularity_geo
-#' - country_iso3
-#' - location_code
-#' - border
-#' - age
-#' - sex
-#' - *_id
-#' - *_tag
-#'
-#' @param x An object of type \code{\link{csfmt_rts_data_v1}}
-#' @param max_isoyear Maximum isoyear
-#' @param max_isoyearweek Maximum isoyearweek
-#' @param max_date Maximum date
-#' @param ... Not used.
-#' @returns csfmt_rts_data_v1, a larger dataset that includes more rows corresponding to more time.
-#' @family csfmt_rts_data
-#' @export
-expand_time_to <- function(x, max_isoyear = NULL, max_isoyearweek = NULL, max_date = NULL, ...) {
-  UseMethod("expand_time_to", x)
-}
-
 #' @method expand_time_to csfmt_rts_data_v1
 #' @export
 expand_time_to.csfmt_rts_data_v1 <- function(x, max_isoyear = NULL, max_isoyearweek = NULL, max_date = NULL, ...) {
@@ -1422,10 +974,6 @@ expand_time_to.csfmt_rts_data_v1 <- function(x, max_isoyear = NULL, max_isoyearw
   return(retval)
 }
 
-expand_time_to_max_isoyear <- function(x, max_isoyear = NULL, ...) {
-  UseMethod("expand_time_to_max_isoyear", x)
-}
-
 expand_time_to_max_isoyear.csfmt_rts_data_v1 <- function(x, max_isoyear = NULL, ...) {
   granularity_time <- NULL
   time_series_id <- NULL
@@ -1474,10 +1022,6 @@ expand_time_to_max_isoyear.csfmt_rts_data_v1 <- function(x, max_isoyear = NULL,
   return(x)
 }
 
-expand_time_to_max_isoyearweek <- function(x, max_isoyearweek = NULL, ...) {
-  UseMethod("expand_time_to_max_isoyearweek", x)
-}
-
 expand_time_to_max_isoyearweek.csfmt_rts_data_v1 <- function(x, max_isoyearweek = NULL, ...) {
   granularity_time <- NULL
   time_series_id <- NULL
@@ -1528,10 +1072,6 @@ expand_time_to_max_isoyearweek.csfmt_rts_data_v1 <- function(x, max_isoyearweek
   return(x)
 }
 
-expand_time_to_max_date <- function(x, max_date = NULL, ...) {
-  UseMethod("expand_time_to_max_date", x)
-}
-
 expand_time_to_max_date.csfmt_rts_data_v1 <- function(x, max_date = NULL, ...) {
   granularity_time <- NULL
   time_series_id <- NULL
